@@ -1,8 +1,7 @@
 """Database file handling.
 """
 
-# pylint: disable=C0103
-#                          Invalid name for type variable
+# pylint: disable= invalid-name, bad-whitespace
 
 import sys
 import os.path
@@ -17,7 +16,7 @@ if __name__ == "__main__":
 import sumolib.ModuleSpec
 import sumolib.JSON
 
-__version__="4.0.2" #VERSION#
+__version__="4.1.1" #VERSION#
 
 assert __version__==sumolib.ModuleSpec.__version__
 assert __version__==sumolib.JSON.__version__
@@ -238,6 +237,39 @@ class DB(sumolib.JSON.Container):
         if linked_ is None:
             return None
         return linked_.get(modulename)
+    def sortby_linkage(self, build_tags, reverse):
+        """sort build so that dependencies of a build always come first."""
+        taglist= sorted(build_tags)
+        keys= { t: 1 for t in taglist }
+        links= { t: self.linked_to(t) for t in taglist }
+        loopcount=0
+        changes= True
+        while changes:
+            loopcount+=1
+            if loopcount > 100:
+                warn("warning: internal error, sortby_linkage failed")
+                break
+            changes= False
+            for t in taglist:
+                for d in links[t]:
+                    if keys.setdefault(d, 1) >= keys[t]:
+                        keys[t]= keys[d]+1
+                        changes= True
+        if not reverse:
+            l= sorted(taglist, key= lambda tag: (keys[tag],tag))
+        else:
+            l= sorted(taglist, key= lambda tag: (-keys[tag],tag))
+        return l
+    def linked_to(self, build_tag):
+        """returns all builds this build is linked to."""
+        build_= self.datadict()[build_tag]
+        linked_ = build_.get("linked")
+        s= set()
+        if linked_ is None:
+            return s
+        for v in linked_.values():
+            s.add(v)
+        return s
     def is_linked_to(self, build_tag, other_build_tag):
         """returns True if there are links to other_build_tag."""
         build_= self.datadict()[build_tag]
@@ -431,6 +463,9 @@ class BuildCache(sumolib.JSON.Container):
         depversiondict[dep_version]= state
     def update_from_builddb(self, builddb, db):
         """update data from a builddb.
+
+        Note: Builds that are disabled, incomplete or unstable are
+              ignored !
         """
         # pylint: disable=R0914
         #                          Too many local variables
@@ -495,7 +530,7 @@ class BuildCache(sumolib.JSON.Container):
 
 def _test():
     """perform internal tests."""
-    import doctest
+    import doctest # pylint: disable= import-outside-toplevel
     doctest.testmod()
 
 if __name__ == "__main__":
