@@ -1,8 +1,7 @@
 """module specifications.
 """
 
-# pylint: disable=C0103
-#                          Invalid name for type variable
+# pylint: disable=invalid-name, bad-whitespace
 
 import sys
 
@@ -17,7 +16,7 @@ if __name__ == "__main__":
 import sumolib.utils
 import sumolib.JSON
 
-__version__="4.0.2" #VERSION#
+__version__="4.1.1" #VERSION#
 
 assert __version__==sumolib.utils.__version__
 assert __version__==sumolib.JSON.__version__
@@ -378,7 +377,7 @@ class Specs():
 
 def _test():
     """perform internal tests."""
-    import doctest
+    import doctest # pylint: disable= import-outside-toplevel
     doctest.testmod()
 
 if __name__ == "__main__":
