@@ -1,11 +1,11 @@
 """Special sumo command completion functions."""
 
-# pylint: disable=C0103
-#                          Invalid name for type variable
+# pylint: disable=invalid-name, bad-whitespace
 
 import sys
 import os.path
 import time
+import sumolib.system
 import sumolib.ModuleSpec
 import sumolib.Dependencies
 
@@ -15,8 +15,9 @@ if __name__ == "__main__":
     # "sumolib.[module]".
     sys.path.append("..")
 
-__version__="4.0.2" #VERSION#
+__version__="4.1.1" #VERSION#
 
+assert __version__==sumolib.system.__version__
 assert __version__==sumolib.ModuleSpec.__version__
 assert __version__==sumolib.Dependencies.__version__
 
@@ -99,7 +100,7 @@ def clear_db_cache():
         # file age in seconds
         age= time.time() - os.path.getmtime(DBCACHE)
         if age>=MAX_AGE:
-            os.remove(DBCACHE)
+            sumolib.system.os_remove(DBCACHE, verbose= False, dry_run= False)
 
 def clear_build_cache():
     """remove the build cache."""
@@ -107,7 +108,8 @@ def clear_build_cache():
         # file age in seconds
         age= time.time() - os.path.getmtime(BUILDCACHE)
         if age>=MAX_AGE:
-            os.remove(BUILDCACHE)
+            sumolib.system.os_remove(BUILDCACHE,
+                                     verbose= False, dry_run= False)
 
 def clear_caches():
     """clear all caches."""
