@@ -16,7 +16,7 @@ import re
 import sumolib.system
 import sumolib.utils
 
-__version__="4.0.2" #VERSION#
+__version__="4.1.1" #VERSION#
 
 assert __version__==sumolib.system.__version__
 assert __version__==sumolib.utils.__version__
@@ -42,7 +42,8 @@ class Repo():
         repository and fails if the repository cannot be reached.
         """
         assert_git()
-        cwd= sumolib.utils.changedir(self.directory)
+        cwd= sumolib.system.changedir(self.directory,
+                                      self.verbose, dry_run=False)
         try:
             (reply,_)= sumolib.system.system(\
                              "git remote show origin",
@@ -52,7 +53,8 @@ class Repo():
             # remote repo could not be contacted.
             return None
         finally:
-            sumolib.utils.changedir(cwd)
+            sumolib.system.changedir(cwd,
+                                     self.verbose, dry_run=False)
         for line in reply.splitlines():
             line= line.strip()
             # look for "Push" url:
@@ -70,13 +72,15 @@ class Repo():
         object are ignored. The matcher parameter may be <None>.
         """
         assert_git()
-        cwd= sumolib.utils.changedir(self.directory)
+        cwd= sumolib.system.changedir(self.directory, self.verbose,
+                                      dry_run= False)
         try:
             cmd= "git status --porcelain"
             (reply,_)= sumolib.system.system(cmd, True, False, None,
                                              self.verbose, self.dry_run)
         finally:
-            sumolib.utils.changedir(cwd)
+            sumolib.system.changedir(cwd, self.verbose,
+                                     dry_run= False)
         changes= False
         for line in reply.splitlines():
             line= line.rstrip()
@@ -100,14 +104,16 @@ class Repo():
             raise AssertionError("cannot compute local patches without "
                                  "a reachable remote repository.")
         assert_git()
-        cwd= sumolib.utils.changedir(self.directory)
+        cwd= sumolib.system.changedir(self.directory,
+                                      self.verbose, dry_run= False)
         try:
             cmd= "git log origin..HEAD"
             (reply,_)= sumolib.system.system(cmd,
                                              True, False, None,
                                              self.verbose, self.dry_run)
         finally:
-            sumolib.utils.changedir(cwd)
+            sumolib.system.changedir(cwd,
+                                     self.verbose, dry_run= False)
         changes= False
         for line in reply.splitlines():
             line= line.strip()
@@ -126,14 +132,16 @@ class Repo():
         patch.
         """
         assert_git()
-        cwd= sumolib.utils.changedir(self.directory)
+        cwd= sumolib.system.changedir(self.directory,
+                                      self.verbose, dry_run= False)
         try:
             (reply,_)= sumolib.system.system(\
                     "git rev-parse --short HEAD",
                     True, False, None,
                     self.verbose, self.dry_run)
         finally:
-            sumolib.utils.changedir(cwd)
+            sumolib.system.changedir(cwd,
+                                     self.verbose, dry_run= False)
         # for uncomitted changes, the revision ends with a "+":
         return reply.splitlines()[0].strip()
     def _tag_on_top(self):
@@ -143,13 +151,15 @@ class Repo():
         """
         curr_rev= self.current_revision
         assert_git()
-        cwd= sumolib.utils.changedir(self.directory)
+        cwd= sumolib.system.changedir(self.directory,
+                                      self.verbose, dry_run= False)
         try:
             cmd= "git tag --points-at %s" % curr_rev
             (reply,_)= sumolib.system.system(cmd, True, False, None,
                                              self.verbose, self.dry_run)
         finally:
-            sumolib.utils.changedir(cwd)
+            sumolib.system.changedir(cwd,
+                                     self.verbose, dry_run= False)
         tags= []
         for line in reply.splitlines():
             line= line.strip()
@@ -288,36 +298,27 @@ class Repo():
         if url is None:
             raise ValueError("spec '%s' has no url" % repr(spec))
         assert_git()
-        cmd= "git clone -q %s %s" % (url, destdir)
         tag= spec.get("tag")
         rev= spec.get("rev")
         if tag and rev:
             raise ValueError("you cannot specify both, tag '%s' and "
                              "revision '%s'" % (tag,rev))
+        opts= "-c advice.detachedHead=false -q"
+        if tag:
+            opts+= " -b %s" % tag
+        if rev:
+            opts+= " -b %s" % rev
+        cmd= "git clone %s %s %s" % (opts, url, destdir)
         sumolib.system.system(cmd, False, False, None, verbose, dry_run)
         # the following to avoid warning if we use "git push" in this
         # repository:
-        cwd= sumolib.utils.changedir(destdir)
+        cwd= sumolib.system.changedir(destdir, verbose, dry_run)
         try:
             cmd="git config push.default simple"
             sumolib.system.system(cmd, False, False, None,
                                   verbose, dry_run)
         finally:
-            sumolib.utils.changedir(cwd)
-        if (tag is None) and (rev is None):
-            return
-        if tag is not None:
-            cmd="git checkout %s" % tag
-        elif rev is not None:
-            cmd="git checkout %s" % rev
-        else:
-            cmd="git checkout master"
-        cmd+=" -q"
-        cwd= sumolib.utils.changedir(destdir)
-        try:
-            sumolib.system.system(cmd, False, False, None, verbose, dry_run)
-        finally:
-            sumolib.utils.changedir(cwd)
+            sumolib.system.changedir(cwd, verbose, dry_run)
     def commit(self, logmessage):
         """commit changes."""
         if not logmessage:
@@ -325,14 +326,16 @@ class Repo():
         else:
             m_param="-m '%s'" % logmessage
         assert_git()
-        cwd= sumolib.utils.changedir(self.directory)
+        cwd= sumolib.system.changedir(self.directory,
+                                      self.verbose, self.dry_run)
         try:
             cmd="git commit -a -q %s" % m_param
             sumolib.system.system(cmd,
                                   False, False, None,
                                   self.verbose, self.dry_run)
         finally:
-            sumolib.utils.changedir(cwd)
+            sumolib.system.changedir(cwd,
+                                     self.verbose, self.dry_run)
         self.local_changes= False
     def push(self):
         """push all changes changes."""
@@ -340,21 +343,24 @@ class Repo():
             raise AssertionError("cannot push local patches without "
                                  "a reachable remote repository.")
         assert_git()
-        cwd= sumolib.utils.changedir(self.directory)
+        cwd= sumolib.system.changedir(self.directory,
+                                      self.verbose, self.dry_run)
         try:
             cmd="git push -q %s" % self.remote_url
             sumolib.system.system(cmd,
                                   True, False, None,
                                   self.verbose, self.dry_run)
         finally:
-            sumolib.utils.changedir(cwd)
+            sumolib.system.changedir(cwd,
+                                     self.verbose, self.dry_run)
     def pull_merge(self):
         """pull changes and try to merge."""
         if self.remote_url is None:
             raise AssertionError("cannot pull patches without "
                                  "a reachable remote repository.")
         assert_git()
-        cwd= sumolib.utils.changedir(self.directory)
+        cwd= sumolib.system.changedir(self.directory,
+                                      self.verbose, self.dry_run)
         try:
             cmd="git fetch %s -q" % self.remote_url
             sumolib.system.system(cmd,
@@ -365,7 +371,8 @@ class Repo():
                                                True, False, None,
                                                self.verbose, self.dry_run)
         finally:
-            sumolib.utils.changedir(cwd)
+            sumolib.system.changedir(cwd,
+                                     self.verbose, self.dry_run)
         if rc:
             msg="error, 'git pull' failed"
             raise IOError(msg)
