@@ -1,8 +1,7 @@
 """Lockfile support.
 """
 
-# pylint: disable=C0103
-#                          Invalid name for type variable
+# pylint: disable=invalid-name, bad-whitespace
 
 import sys
 import os
@@ -16,14 +15,14 @@ if __name__ == "__main__":
     # "sumolib.[module]".
     sys.path.append("..")
 
-# pylint: disable=wrong-import-position
-import sumolib.system
-# pylint: enable=wrong-import-position
+import sumolib.system # pylint: disable=wrong-import-position
 
-__version__="4.0.2" #VERSION#
+__version__="4.1.1" #VERSION#
 
 use_lockfile= True
 
+assert __version__==sumolib.system.__version__
+
 try:
     import pwd
 except ImportError:
@@ -173,7 +172,8 @@ class MyLock():
         else:
             for f in os.listdir(self.lockname):
                 os.unlink(os.path.join(self.lockname,f))
-            os.rmdir(self.lockname)
+            sumolib.system.os_rmdir(self.lockname,
+                                    verbose= False, dry_run= False)
         self._has_lock= False
     def filename(self, filename_= None):
         """gets or sets the name of the file that should be locked."""
@@ -220,7 +220,7 @@ def edit_with_lock(filename, verbose, dry_run):
 
 def _test():
     """perform internal tests."""
-    import doctest
+    import doctest # pylint: disable= import-outside-toplevel
     doctest.testmod()
 
 if __name__ == "__main__":
