@@ -1,16 +1,15 @@
 """patch file support."""
 
-# pylint: disable=C0103
-#                          Invalid name for type variable
+# pylint: disable=invalid-name, bad-whitespace
 
 import os
 import subprocess
-import sumolib.utils
+import sumolib.system
 import sumolib.fileurl
 
-__version__="4.0.2" #VERSION#
+__version__="4.1.1" #VERSION#
 
-assert __version__==sumolib.utils.__version__
+assert __version__==sumolib.system.__version__
 assert __version__==sumolib.fileurl.__version__
 
 def assert_patch():
@@ -27,7 +26,10 @@ def call_patch(patch_file, target_dir, verbose, dry_run):
     cmd= "patch -p1"
     if dry_run or verbose:
         print("> cd %s && %s < %s" % (target_dir, cmd, patch_file))
-    old_dir= sumolib.utils.changedir(target_dir)
+    if dry_run:
+        return
+    old_dir= sumolib.system.changedir(target_dir,
+                                      verbose= False, dry_run= False)
     try:
         inp= open(patch_file, "r")
         p= subprocess.Popen(cmd, shell=True,
@@ -35,7 +37,7 @@ def call_patch(patch_file, target_dir, verbose, dry_run):
                             close_fds=True)
         p.wait()
     finally:
-        sumolib.utils.changedir(old_dir)
+        sumolib.system.changedir(old_dir, verbose= False, dry_run= False)
         inp.close()
     if p.returncode != 0:
         raise IOError("patch %s could not be fully applied" % patch_file)
