@@ -1,8 +1,8 @@
 """Repository support
 """
 
-# pylint: disable=C0103
-#                          Invalid name for type variable
+# pylint: disable=invalid-name, bad-whitespace
+
 import os.path
 import sys
 
@@ -18,7 +18,7 @@ import sumolib.git
 import sumolib.subversion # "svn"
 import sumolib.cvs
 
-__version__="4.0.2" #VERSION#
+__version__="4.1.1" #VERSION#
 
 assert __version__==sumolib.utils.__version__
 assert __version__==sumolib.lock.__version__
@@ -122,14 +122,12 @@ def src_from_dir(directory, hints, verbose, dry_run):
 
 def apply_commands(cmds, target_dir, verbose, dry_run):
     """apply custom commands in module."""
-    old_dir= sumolib.utils.changedir(target_dir)
-    if dry_run or verbose:
-        print("> cd %s" % target_dir)
+    old_dir= sumolib.system.changedir(target_dir, verbose, dry_run)
     try:
         for cmd in cmds:
             sumolib.system.system(cmd, False, False, None, verbose, dry_run)
     finally:
-        sumolib.utils.changedir(old_dir)
+        sumolib.system.changedir(old_dir, verbose, dry_run)
 
 def checkout(sourcespec, destdir, lock_timeout, verbose, dry_run):
     """check out a working copy.
@@ -580,12 +578,14 @@ class ManagedRepo():
                                  self.directory)
 
         no_write_access= False
+        errmsg= None
         # get a repository lock:
         try:
             self.lock.lock()
-        except (sumolib.lock.AccessError, sumolib.lock.LockedError):
+        except (sumolib.lock.AccessError, sumolib.lock.LockedError) as e:
             # we do not have write access on the repository:
             no_write_access= True
+            errmsg= str(e)
 
         if no_write_access:
             # basically disable all action on the repository:
@@ -593,9 +593,10 @@ class ManagedRepo():
             # ManagedRepo object.
             if self.mode!='get':
                 sys.stdout.flush()
-                sys.stderr.write("warning: no write access to dependency "
-                                 "database repository, disabling "
-                                 "repository operations\n")
+                sys.stderr.write(("warning: locking the dependency database "
+                                  "failed: '%s'. Disabling repository "
+                                  "operations on the dependency database "
+                                  "for now.") % errmsg)
                 sys.stderr.flush()
             self.sourcespec= None
             return
@@ -676,7 +677,7 @@ class ManagedRepo():
 
 def _test():
     """perform internal tests."""
-    import doctest
+    import doctest # pylint: disable= import-outside-toplevel
     doctest.testmod()
 
 if __name__ == "__main__":
